package com.jkcredit.illegal.info.service.impl;

import com.alibaba.fastjson.JSON;
import com.jkcredit.illegal.info.constant.CommonConstant;
import com.jkcredit.illegal.info.model.*;
import com.jkcredit.illegal.info.service.IllegalInfoTestService;
import com.jkcredit.illegal.info.util.OkHttpUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.commons.CommonsMultipartFile;

import java.util.Random;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/9/22 11:51
 * @version: V1.0
 **/
@Slf4j
@Service
public class IllegalInfoTestServiceImpl implements IllegalInfoTestService {
    @Value("${illegalInfo.url}")
    private String illegalInfoUrl;
    @Value("${illegalInfo.vehicleUrl}")
    private String vehicleIllegalInfoUrl;

    private static final Log CHARGE_LOGGER = LogFactory.getLog("CHARGE_LOGGER");
    private static final Log TEST_LOGGER = LogFactory.getLog("TEST_LOGGER");
    @Override
    public IllegalInfoResult checkIllegalInfoTest(IllegalInfoRequestParam requestParams) {
        String traceId = "test-" + System.currentTimeMillis() + getRandomNumber(5);
        requestParams.setTraceId(traceId);
        String body = JSON.toJSONString(requestParams);

        Long startTime = System.currentTimeMillis();
        String result = OkHttpUtil.doPost(illegalInfoUrl, body, CommonConstant.PERSON_TIME_OUT);
        TEST_LOGGER.info("调用上游接口-测试-流水号:" + requestParams.getTraceId() + ", 入参:" + body + ", 返回:" + result
                + ", 时延:" + (System.currentTimeMillis() - startTime));
        if (StringUtils.isBlank(result)) {
            TEST_LOGGER.info("调用上游接口-测试-流水号:" + requestParams.getTraceId() + ", 入参:" + body);
        }

        IllegalInfoResult illegalInfoResult;
        try {
            if (StringUtils.isBlank(result)) {
                illegalInfoResult = new IllegalInfoResult().normalResult();
                CHARGE_LOGGER.info(JSON.toJSONString(new IllegalInfoChargeObject(illegalInfoResult, false, requestParams.getTraceId())));
                return illegalInfoResult;
            } else {
                illegalInfoResult = JSON.toJavaObject(JSON.parseObject(result), IllegalInfoResult.class);
            }
        } catch (Exception e) {
            log.error("调用上游接口-流水号:{}, 入参:{}, 解析上游返回异常:{}", requestParams.getTraceId(), body, e);
            illegalInfoResult = new IllegalInfoResult().normalResult();
            CHARGE_LOGGER.info(JSON.toJSONString(new IllegalInfoChargeObject(illegalInfoResult, false, requestParams.getTraceId())));
            return illegalInfoResult;
        }

        // 返回4个参数，code0表示结果正常，其他表示异常
        if (!illegalInfoResult.getCode().equals("0")
                || illegalInfoResult.getIsDrugs().equals("2")
                || illegalInfoResult.getIsEscape().equals("2")
                || illegalInfoResult.getIsPedigree().equals("2")) {
            // 查询错误，不计费
            CHARGE_LOGGER.info(JSON.toJSONString(new IllegalInfoChargeObject(illegalInfoResult, false, requestParams.getTraceId())));
        } else {
            // 查询成功，计费
            CHARGE_LOGGER.info(JSON.toJSONString(new IllegalInfoChargeObject(illegalInfoResult, true, requestParams.getTraceId())));
        }
        return illegalInfoResult;
    }

    @Override
    public VehicleIllegalInfoResult checkVehicleIllegalInfo(VehicleIllegalInfoRequestParam requestParam) {
        String traceId = "test-" + System.currentTimeMillis() + getRandomNumber(5);
        requestParam.setTraceId(traceId);
        String body = JSON.toJSONString(requestParam);

        Long startTime = System.currentTimeMillis();
        String result = OkHttpUtil.doPost(vehicleIllegalInfoUrl, body, CommonConstant.VEHICLE_TIME_OUT);
        TEST_LOGGER.info("调用上游接口-测试-流水号:" + requestParam.getTraceId() + ", 入参:" + body + ", 返回:" + result
                + ", 时延:" + (System.currentTimeMillis() - startTime));
        if (StringUtils.isBlank(result)) {
            TEST_LOGGER.info("调用上游接口-测试-流水号:" + requestParam.getTraceId() + ", 入参:" + body);
            return null;
        }
        VehicleIllegalInfoResult vehicleIllegalInfoResult = JSON.toJavaObject(JSON.parseObject(result), VehicleIllegalInfoResult.class);
        // code0表示结果正常，其他表示异常
        if (!vehicleIllegalInfoResult.getCode().equals("0")
                || vehicleIllegalInfoResult.getResult().equals("2")) {
            // 查询错误，不计费
            CHARGE_LOGGER.info(JSON.toJSONString(new VehicleIllegalInfoChargeObject(vehicleIllegalInfoResult, false, requestParam.getTraceId())));
        } else {
            // 查询成功，计费
            CHARGE_LOGGER.info(JSON.toJSONString(new VehicleIllegalInfoChargeObject(vehicleIllegalInfoResult, true, requestParam.getTraceId())));
        }
        return vehicleIllegalInfoResult;
    }

    private static String getRandomNumber(int length) {
        StringBuilder sb = new StringBuilder();
        Random rand = new Random();
        for (int i = 0; i < length; i++) {
            sb.append(rand.nextInt(10));
        }
        String data = sb.toString();
        return data;
    }
}
