package com.jkcredit.illegal.info.util;

import com.jkcredit.illegal.info.constant.CommonConstant;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;

import javax.net.ssl.*;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.SocketTimeoutException;
import java.security.KeyManagementException;
import java.security.KeyStore;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.cert.Certificate;
import java.security.cert.CertificateFactory;
import java.util.concurrent.TimeUnit;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/11/17 14:20
 * @version: V1.0
 **/
@Slf4j
public class OkHttpUtil {
    private static OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    public static String doPost(String url, String body, int outTime) {
        MediaType mediaType = MediaType.parse(CommonConstant.MEDIA_TYPE);
        RequestBody requestBody = RequestBody.create(mediaType, body);

        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
        OkHttpClient client = okHttpClient.newBuilder()
                .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                .hostnameVerifier(new RxUtil.TrustAllHostnameVerifier())
                .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                .readTimeout(outTime, TimeUnit.MILLISECONDS)
                .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                .build();
        String responseContext = "";
        try {
            Response response = client.newCall(okRequest).execute();
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            response.close();
        } catch (SocketTimeoutException ste) {
            log.info("doPost, 参数：{}-SocketTimeoutException：", body, ste);
        } catch (IOException ioe) {
            log.info("doPost, 参数：{}-IOException：{}", body, ioe);
        } catch (Exception e) {
            log.info("doPost, 参数：{}-exception：{}", body, e);
        }
        return responseContext;
    }

    public static String doHttpPost(String url, String jsonString) {
        MediaType mediaType = MediaType.parse(CommonConstant.APPLICATION_JSON_UTF8_VALUE);
        RequestBody requestBody = RequestBody.create(mediaType, jsonString);
        Request okRequest = new Request.Builder().post(requestBody).url(url).build();
        OkHttpClient client = okHttpClient.newBuilder()
                .connectTimeout(CommonConstant.DING_TIME_OUT, TimeUnit.MILLISECONDS)
                .readTimeout(CommonConstant.DING_TIME_OUT, TimeUnit.MILLISECONDS)
                .writeTimeout(CommonConstant.DING_TIME_OUT, TimeUnit.MILLISECONDS)
                .build();

        try {
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            return responseContext;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
}
